============================================
Model Mommy: Smart fixtures for better tests
============================================

*Model-mommy* offers you a smart way to create fixtures for testing in Django.
With a simple and powerful API you can create many objects with a single line of code.

.. image:: https://travis-ci.org/vandersonmota/model_mommy.png?branch=master
        :target: https://travis-ci.org/vandersonmota/model_mommy

Install
=======

.. code-block:: console

    pip install model_mommy


Usage and Info
==============

*     http://model-mommy.readthedocs.org/

